class LearningObject < ActiveRecord::Base
  include Metadatable

  has_and_belongs_to_many :topics

  has_many :collection_items, as: :collectionable
  has_many :collections, through: :collection_items

  has_many :complaints
  has_many :reviews, as: :reviewable

  has_many :views, as: :viewable
  has_many :downloads, as: :downloadable
  has_many :likes, as: :likeable
  has_many :shares, as: :shareable

  belongs_to :publisher, polymorphic: true

  def categories
    get_metadata_value_of 'dc.subject.category'
  end

  def liked?(user)
    return false if likes.where(user: user).blank?

    true
  end

  def like(user)
    Like.create(user: user, likeable: self)
  end

  def dislike(user)
    Like.where(user: user, likeable: self).destroy_all
  end
end
